==> digikam_7.1.0.orig.tar.xz: digikam-7.1.0/project/bundles/flatpak/README.md <==
FlatPak KDE Applications Repository
-----------------------------------

Bundle is processed daily by the continuous integration script used by KDE server.
Bundle is deployed automatically on KDE Applications Flatpak testing repository.

- Front page;      https://kde.org/applications/en/graphics/org.kde.digikam
- Status;          https://binary-factory.kde.org/view/Flatpak/job/Digikam_flatpak/
- Configuration:   https://invent.kde.org/kde/flatpak-kde-applications/-/blob/master/org.kde.digikam.remoteapp  (hook)
                   ./org.kde.digikam.json
- Repository:      https://distribute.kde.org/kdeapps.flatpakrepo


FlatHub Repository
------------------

Bundle is processed when new release is published only.

- Front page:      https://flathub.org/apps/details/org.kde.digikam
- Status;          https://flathub.org/builds/#/apps/org.kde.digikam
- Configuration:   https://github.com/flathub/org.kde.digikam
- Repository:      https://dl.flathub.org/build-repo/


Linux Installers
----------------

You can handle the digiKam Flatpak bundle on Linux desktop installer as Plasma Discover or Gnome Software.

- Plasma Discover: https://userbase.kde.org/Discover

[![](https://i.imgur.com/IHxNhDT.png "Settings Kdeapps testings source repository in Plasma Discover Application")](https://imgur.com/IHxNhDT)
[![](https://i.imgur.com/Gu83kFI.png "digiKam Flatpak bundle Properties in Plasma Discover Application")](https://imgur.com/Gu83kFI)

- Gnome Software:  https://wiki.gnome.org/Apps/Software

==> digikam_7.5.0.orig.tar.xz: digikam-7.5.0/project/bundles/flatpak/README.md <==
FlatPak KDE Applications Repository
-----------------------------------

Bundle is processed daily by the continuous integration script used by KDE server.
Bundle is deployed automatically on KDE Applications Flatpak testing repository.

- Front page;      https://apps.kde.org/digikam/
- Status;          https://binary-factory.kde.org/view/Flatpak/job/Digikam_x86_64_flatpak/
- Configuration:   https://invent.kde.org/kde/flatpak-kde-applications/-/blob/master/org.kde.digikam.remoteapp  (hook)
                   ./org.kde.digikam.json                                                                       (target)
- Repository:      https://distribute.kde.org/kdeapps.flatpakrepo


FlatHub Repository
------------------

Bundle is processed when new release is published only.

- Front page:      https://flathub.org/apps/details/org.kde.digikam
- Status;          https://flathub.org/builds/#/apps/org.kde.digikam
- Configuration:   https://github.com/flathub/org.kde.digikam
- Repository:      https://dl.flathub.org/build-repo/


Linux Installers
----------------

You can handle the digiKam Flatpak bundle on Linux desktop installer as Plasma Discover or Gnome Software.

- Plasma Discover: https://userbase.kde.org/Discover

[![](https://i.imgur.com/IHxNhDT.png "Settings Kdeapps testings source repository in Plasma Discover Application")](https://imgur.com/IHxNhDT)
[![](https://i.imgur.com/Gu83kFI.png "digiKam Flatpak bundle Properties in Plasma Discover Application")](https://imgur.com/Gu83kFI)

- Gnome Software:  https://wiki.gnome.org/Apps/Software
